/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.prognose;

import de.bsvrz.sys.funclib.bitctrl.modell.DatensatzUpdateEvent;
import de.bsvrz.sys.funclib.bitctrl.modell.DatensatzUpdateListener;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.objekte.MessQuerschnittAllgemein;
import de.bsvrz.sys.funclib.bitctrl.modell.verkehr.parameter.PdFundamentalDiagramm;
import de.bsvrz.sys.funclib.bitctrl.util.UndefiniertException;

/**
 * Die Repräsentation eines Fundamentaldiagramms für einen Messquerschnitt.<br>
 * Das Fundamentaldiagramm wird als Parameter für den Messquerschnitt zur
 * Verfügung gestellt. Die Baustellensimulation benötigt lediglich den Wert Q0
 * zur Bestimmung der Restkapazität der Baustelle ausserhalb der
 * Gültigkeitszeit.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class FundamentalDiagramm implements DatensatzUpdateListener {

	/**
	 * das Objekt (der MQ) auf den sich das Diagramm bezieht.
	 */
	private MessQuerschnittAllgemein mqObjekt;

	@Override
	public void datensatzAktualisiert(final DatensatzUpdateEvent event) {
		// die Aktualisierung ist ohne Bedeutung, da der Wert bei Bedarf
		// ausgelesen wird

	}

	/**
	 * liefert den Q0-Wert des Fundamentaldiagramms.
	 *
	 * @return dne Wert
	 * @throws UndefiniertException
	 *             es konnte kein Q0-Wert bestimmt werden
	 */
	public double getQ0() throws UndefiniertException {

		if (mqObjekt == null) {
			throw new UndefiniertException("Kein MQ für die Bestimmung des Fundamantaldiagramms definiert");
		}

		final PdFundamentalDiagramm.Daten daten = mqObjekt.getParameterDatensatz(PdFundamentalDiagramm.class)
				.getDatum();
		if ((daten == null) || (!daten.isValid())) {
			throw new UndefiniertException("Für den MQ: " + mqObjekt + " ist kein Fundamentaldiagramm verfügbar");
		}

		return daten.getQ0();
	}

	/**
	 * setzt den aktuellen Messquerschnitt, dessen Daten das Fundamentaldiagramm
	 * bereithält.
	 *
	 * @param mq
	 *            das Systemobjekt, das den Messquerschnitt in der Konfiguration
	 *            des Datenverteilers repräsentiert
	 */
	public final void setMq(final MessQuerschnittAllgemein mq) {
		if (mqObjekt != null) {
			mqObjekt.getParameterDatensatz(PdFundamentalDiagramm.class).removeUpdateListener(this);
		}
		mqObjekt = mq;
		if (mqObjekt != null) {
			mqObjekt.getParameterDatensatz(PdFundamentalDiagramm.class).addUpdateListener(this);
		}
	}

}
