/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.verwaltung;

/**
 * die Repräsentation eines Stauobjekts innerhalb der Stauprognose eine
 * Baustelle.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class BssSchritt {

	private final long zeitPunkt;
	private final long laenge;
	private final long verlustZeit;
	private final long anzahlFahrzeugeImStau;

	/**
	 * erzeugt eine Instanz des Stauschritts.
	 *
	 * @param zeitPunkt
	 *            des Perechnungsschritts
	 * @param laenge
	 *            die für den Zeitpunkt berechnete Staulänge
	 * @param verlustZeit
	 *            die für den Zeitpunkt berechnete Verlustzeit
	 * @param anzahlFahrzeugeImStau
	 *            die Anzahl der Fahrzeuge (normierte PKW-Einheiten) im Intervall
	 */
	public BssSchritt(long zeitPunkt, long laenge, long verlustZeit, long anzahlFahrzeugeImStau) {
		this.zeitPunkt = zeitPunkt;
		this.laenge = laenge;
		this.verlustZeit = verlustZeit;
		this.anzahlFahrzeugeImStau = anzahlFahrzeugeImStau;
	}

	public long getZeitPunkt() {
		return zeitPunkt;
	}

	public long getLaenge() {
		return laenge;
	}

	public long getVerlustZeit() {
		return verlustZeit;
	}

	public long getAnzahlFahrzeugeImStau() {
		return anzahlFahrzeugeImStau;
	}
}
